"""Create mesh for lwru2 validation of the Oshiri island tsunami
"""


from anuga.pmesh.mesh import *
from anuga.coordinate_transforms.geo_reference import Geo_reference


def generate(mesh_filename, distance_offshore, beach_length, longshore_length, is_course = False):
    #Basic geometry
    
    xright  = beach_length
    ybottom = 0
    ytop    = longshore_length
    xleft = -distance_offshore

    #Outline 
    point_sw = [xleft, ybottom]
    point_se = [xright, ybottom]
    point_nw = [xleft, ytop]    
    point_ne = [xright, ytop]
  

    m = Mesh()

    #Boundary
    points = [point_sw,   #se
              point_nw,
              point_ne, 
              point_se, 
              ]
    
    segments = [[0,1], [1,2], [2,3], [3,0]
                        ]  #The outer border
    
    segment_tags = {'wall':[1,3],'edge':[2], 'back':[0]} # '':[6]
        
    m.add_points_and_segments(points, segments, segment_tags)
    
    if is_course:
        m.generate_mesh(maximum_triangle_area=20)
    else:
        m.generate_mesh(maximum_triangle_area=0.5)

    m.export_mesh_file(mesh_filename)
    print "mesh created"

#-------------------------------------------------------------
if __name__ == "__main__":
    generate("aa.tsh", 0.75, is_course = True)
